@@ -16,7 +16,7 @@ def create_column(feature_df, parts_num):
     print("\n> start generating the feature: Parts of waking hours")
     wake_time_datetime_list = convert_time_str_to_datetime(feature_df["WAKE_TIME"])
     sleep_time_datetime_list = convert_time_str_to_datetime(feature_df["SLEEP_TIME"])
-    prompt_time_datetime_list = feature_df["Prompt_Local_DateTime"]
+    prompt_time_datetime_list = feature_df["Actual_Prompt_Local_DateTime"]
 
     proximity_to_wake_time_column = [(y - x).total_seconds() / 60 if ((type(x) != str) and (type(y) != str)) else "NF"
                                      for x, y in zip(wake_time_datetime_list, prompt_time_datetime_list)]
