@@ -28,7 +28,7 @@ columns_list = ["Prompt_Type", "Study_Mode", "Initial_Prompt_Local_Time", "Initi
                 'Reprompt3_Prompt_Local_Time', 'Reprompt3_Prompt_UnixTime',
                 'Reprompt4_Prompt_Date', 'Reprompt4_Prompt_Local_Time',
                 'Reprompt4_Prompt_UnixTime', 'Reprompt5_Prompt_Date',
-                'Reprompt5_Prompt_Local_Time', 'Reprompt5_Prompt_UnixTime']
+                'Reprompt5_Prompt_Local_Time', 'Reprompt5_Prompt_UnixTime', "Question_1_Answer_Unixtime"]
 
 prompt_type_excluded = ['None_Sleep', 'None_Empty']
 
